<?php
/**
 * The Customizer for displaying Custom colors
 *
 * @package truckage
 */

function truckage_customize_register( $wp_customize ) {	
	
	/*--------------------------------------------------------------------------------------------------------------------
													Custom colors  
--------------------------------------------------------------------------------------------------------------------*/
	// 	Accent color
	$wp_customize->add_setting( 'accent_color', array(
		'default'   => '#dd1b3c',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'accent_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Accent', 'theme' ),
	) ) );
	
	// 	Accent color 1
	$wp_customize->add_setting( 'accent_color1', array(
		'default'   => '#212331',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'accent_color1', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Accent1', 'theme' ),
	) ) );
	
	// 	Body color
	$wp_customize->add_setting( 'p_color', array(
		'default'   => '#000',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'p_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Paragraph', 'theme' ),
	) ) );
	
	// 	Heading colors
	
	$wp_customize->add_setting( 'head_color', array(
		'default'   => '#212331',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'head_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Title H1', 'theme' ),
	) ) );
	
	// 	Link color
	$wp_customize->add_setting( 'link_color', array(
		'default'   => '#212331',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Link', 'theme' ),
	) ) );
	
	// 	Link Hover color
	$wp_customize->add_setting( 'link_hover', array(
		'default'   => '#212331',
		'transport' => 'refresh',
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	) );
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_hover', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Link Hover', 'theme' ),
	) ) );
	
	/*--------------------------------------------------------------------------------------------------------------------
													Typography  
--------------------------------------------------------------------------------------------------------------------*/
	include('fonts.php');
	
	$wp_customize->add_panel( 'typography', array(
		'title' => 'Typography',
	) );
	
	/** Body Text Section **/
	
	$wp_customize->add_section('body_text', array(
		'title'      => __( 'Body Text', 'body_text' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** Body font family **/
	
	$wp_customize->add_setting('body_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_font_family',
		array(
		'label'      => __('Font Family', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
	)) );
	
	/** Body font style **/
	
	$wp_customize->add_setting('body_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_font_style',
		array(
		'label'      => __('Font Style', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_font_style',
		'type'       => 'select',
		'choices' =>array(
			'Normal' => 'Normal',
			'Italic' => 'Italic',
			'Oblique'=> 'Oblique',
			'Inherit'=> 'Inherit',
		),
	)) );
	
	/** Body font Weight **/
	
	$wp_customize->add_setting('body_font_weight', array(
		'default'        => '400',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_font_weight',
		array(
		'label'      => __('Font Weight', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	
	/** Body font size**/
	
	$wp_customize->add_setting('body_font_size', array(
		'default'        => '16',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_font_size',
		array(
		'label'      => __('Font Size, px', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** Body Line Height**/
	
	$wp_customize->add_setting('body_line_height', array(
		'default'        => '1.8',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_line_height',
		array(
		'label'      => __('Line Height', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );
	
	/** Body Letter Spacing**/
	
	$wp_customize->add_setting('body_letter_spacing', array(
		'default'        => '1',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/** Body Text Align**/
	
	$wp_customize->add_setting('body_text_align', array(
		'default'        => 'Left',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'body_text_align',
		array(
		'label'      => __('Text Align', 'body_text'),
		'section'    => 'body_text',
		'settings'   => 'body_text_align',
		'type'       => 'select',
		'choices' => array(
			'Inherit' => 'Inherit',
			'Center' => 'Center',
			'Right' => 'Right',
			'Left' => 'Left',
			'Justify' => 'Justify',
		),
	)) );
	
	/** H1 Section **/
	
	$wp_customize->add_section('h1_heading', array(
		'title'      => __( 'H1 Heading', 'h1_heading' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** H1 font family **/
	
	$wp_customize->add_setting('h1_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_font_family',
		array(
		'label'      => __('Font Family', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
	)) );
	
	/** H1 font style **/
	
	$wp_customize->add_setting('h1_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_font_style',
		array(
		'label'      => __('Font Style', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_font_style',
		'type'       => 'select',
		'choices' =>array(
			'Normal' => 'Normal',
			'Italic' => 'Italic',
			'Oblique'=> 'Oblique',
			'Inherit'=> 'Inherit',
		),
	)) );
	
	/** H1 font Weight **/
	
	$wp_customize->add_setting('h1_font_weight', array(
		'default'        => '500',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_font_weight',
		array(
		'label'      => __('Font Weight', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	/** H1 font size**/
	
	$wp_customize->add_setting('h1_font_size', array(
		'default'        => '40',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_font_size',
		array(
		'label'      => __('Font Size, px', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** H1 Line Height**/
	
	$wp_customize->add_setting('h1_line_height', array(
		'default'        => '1.139',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_line_height',
		array(
		'label'      => __('Line Height', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );
	
	/** H1 Letter Spacing**/
	
	$wp_customize->add_setting('h1_letter_spacing', array(
		'default'        => '0',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/**H1 Text Align**/
	
	$wp_customize->add_setting('h1_text_align', array(
		'default'        => 'Inherit',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h1_text_align',
		array(
		'label'      => __('Text Align', 'h1_heading'),
		'section'    => 'h1_heading',
		'settings'   => 'h1_text_align',
		'type'       => 'select',
		'choices' => array(
			'Inherit' => 'Inherit',
			'Center' => 'Center',
			'Right' => 'Right',
			'Left' => 'Left',
			'Justify' => 'Justify',
		),
	)) );
	
	/** H2 Section **/
	
	$wp_customize->add_section('h2_heading', array(
		'title'      => __( 'H2 Heading', 'h2_heading' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** H2 font family **/
	
	$wp_customize->add_setting('h2_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_font_family',
		array(
		'label'      => __('Font Family', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
	)) );
	
	/** H2 font style **/
	
	$wp_customize->add_setting('h2_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_font_style',
		array(
		'label'      => __('Font Style', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_font_style',
		'type'       => 'select',
		'choices' =>array(
			'Normal' => 'Normal',
			'Italic' => 'Italic',
			'Oblique'=> 'Oblique',
			'Inherit'=> 'Inherit',
		),
	)) );
	
	/** H2 font Weight **/
	
	$wp_customize->add_setting('h2_font_weight', array(
		'default'        => '500',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_font_weight',
		array(
		'label'      => __('Font Weight', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	/** H2 font size**/
	
	$wp_customize->add_setting('h2_font_size', array(
		'default'        => '32',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_font_size',
		array(
		'label'      => __('Font Size, px', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** H2 Line Height**/
	
	$wp_customize->add_setting('h2_line_height', array(
		'default'        => '1.139',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_line_height',
		array(
		'label'      => __('Line Height', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );
	
	/** H2 Letter Spacing**/
	
	$wp_customize->add_setting('h2_letter_spacing', array(
		'default'        => '0',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/**H2 Text Align**/
	
	$wp_customize->add_setting('h2_text_align', array(
		'default'        => 'Inherit',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h2_text_align',
		array(
		'label'      => __('Text Align', 'h2_heading'),
		'section'    => 'h2_heading',
		'settings'   => 'h2_text_align',
		'type'       => 'select',
		'choices' => array(
		'Inherit' => 'Inherit',
		'Center' => 'Center',
		'Right' => 'Right',
		'Left' => 'Left',
		'Justify' => 'Justify',
		),
	)) );
	
	/** H3 Section **/
	
	$wp_customize->add_section('h3_heading', array(
		'title'      => __( 'H3 Heading', 'h3_heading' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** H3 font family **/
	
	$wp_customize->add_setting('h3_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_font_family',
		array(
		'label'      => __('Font Family', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
	)) );
	
	/** H3 font style **/
	
	$wp_customize->add_setting('h3_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_font_style',
		array(
		'label'      => __('Font Style', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_font_style',
		'type'       => 'select',
		'choices' =>array(
			'Normal' => 'Normal',
			'Italic' => 'Italic',
			'Oblique'=> 'Oblique',
			'Inherit'=> 'Inherit',
		),
	)) );
	
	/** H3 font Weight **/
	
	$wp_customize->add_setting('h3_font_weight', array(
		'default'        => '500',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_font_weight',
		array(
		'label'      => __('Font Weight', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	/** H3 font size**/
	
	$wp_customize->add_setting('h3_font_size', array(
		'default'        => '28',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_font_size',
		array(
		'label'      => __('Font Size, px', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** H3 Line Height**/
	
	$wp_customize->add_setting('h3_line_height', array(
		'default'        => '1.139',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_line_height',
		array(
		'label'      => __('Line Height', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );
	
	/** H3 Letter Spacing**/
	
	$wp_customize->add_setting('h3_letter_spacing', array(
		'default'        => '0',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/**H3 Text Align**/
	
	$wp_customize->add_setting('h3_text_align', array(
		'default'        => 'Inherit',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h3_text_align',
	array(
		'label'      => __('Text Align', 'h3_heading'),
		'section'    => 'h3_heading',
		'settings'   => 'h3_text_align',
		'type'       => 'select',
		'choices' => array(
		'Inherit' => 'Inherit',
		'Center' => 'Center',
		'Right' => 'Right',
		'Left' => 'Left',
		'Justify' => 'Justify',
		),
	)) );
	
	/** H4 Section **/
	
	$wp_customize->add_section('h4_heading', array(
		'title'      => __( 'H4 Heading', 'h4_heading' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** H4 font family **/
	
	$wp_customize->add_setting('h4_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_font_family',
		array(
		'label'      => __('Font Family', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
		)) );
	
	
	$wp_customize->add_setting('h4_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_font_style',
		array(
		'label'      => __('Font Style', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_font_style',
		'type'       => 'select',
		'choices' =>array(
		'Normal' => 'Normal',
		'Italic' => 'Italic',
		'Oblique'=> 'Oblique',
		'Inherit'=> 'Inherit',
		),
	)) );
	
	/** H4 font Weight **/
	
	$wp_customize->add_setting('h4_font_weight', array(
		'default'        => '500',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',	
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_font_weight',
		array(
		'label'      => __('Font Weight', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	/** H4 font size**/
	
	$wp_customize->add_setting('h4_font_size', array(
		'default'        => '28',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_font_size',
		array(
		'label'      => __('Font Size, px', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** H4 Line Height**/
	
	$wp_customize->add_setting('h4_line_height', array(
		'default'        => '1.139',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_line_height',
		array(
		'label'      => __('Line Height', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );
	
	/** H4 Letter Spacing**/
	
	$wp_customize->add_setting('h4_letter_spacing', array(
		'default'        => '0',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/**H4 Text Align**/
	
	$wp_customize->add_setting('h4_text_align', array(
		'default'        => 'Inherit',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h4_text_align',
		array(
		'label'      => __('Text Align', 'h4_heading'),
		'section'    => 'h4_heading',
		'settings'   => 'h4_text_align',
		'type'       => 'select',
		'choices' => array(
			'Inherit' => 'Inherit',
			'Center' => 'Center',
			'Right' => 'Right',
			'Left' => 'Left',
			'Justify' => 'Justify',
		),
	)) );
	
	/** H4 Section **/
	
	$wp_customize->add_section('h5_heading', array(
		'title'      => __( 'H5 Heading', 'h5_heading' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** H5 font family **/
	
	$wp_customize->add_setting('h5_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_font_family',
		array(
		'label'      => __('Font Family', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
	)) );
		
	/** H5 font style **/
	
	$wp_customize->add_setting('h5_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_font_style',
		array(
		'label'      => __('Font Style', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_font_style',
		'type'       => 'select',
		'choices' =>array(
			'Normal' => 'Normal',
			'Italic' => 'Italic',
			'Oblique'=> 'Oblique',
			'Inherit'=> 'Inherit',
		),
	)) );
	
	/** H5 font Weight **/
	$wp_customize->add_setting('h5_font_weight', array(
		'default'        => '500',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_font_weight',
		array(
		'label'      => __('Font Weight', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	/** H5 font size**/
	
	$wp_customize->add_setting('h5_font_size', array(
		'default'        => '18',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_font_size',
		array(
		'label'      => __('Font Size, px', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** H5 Line Height**/
	
	$wp_customize->add_setting('h5_line_height', array(
		'default'        => '1.139',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_line_height',
		array(
		'label'      => __('Line Height', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );
	
	/** H5 Letter Spacing**/
	
	$wp_customize->add_setting('h5_letter_spacing', array(
		'default'        => '0',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/**H5 Text Align**/
	
	$wp_customize->add_setting('h5_text_align', array(
		'default'        => 'Inherit',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h5_text_align',
		array(
		'label'      => __('Text Align', 'h5_heading'),
		'section'    => 'h5_heading',
		'settings'   => 'h5_text_align',
		'type'       => 'select',
		'choices' => array(
			'Inherit' => 'Inherit',
			'Center' => 'Center',
			'Right' => 'Right',
			'Left' => 'Left',
			'Justify' => 'Justify',
		),
	)) );
	
	/** H4 Section **/
	
	$wp_customize->add_section('h6_heading', array(
		'title'      => __( 'H6 Heading', 'h6_heading' ),
		'priority'   => 30,
		'panel' => 'typography',
	));
	
	/** H6 font family **/
	
	$wp_customize->add_setting('h6_font_family', array(
		'default'        => 'Josefin Sans',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_font_family',
		array(
		'label'      => __('Font Family', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_font_family',
		'type'       => 'select',
		'choices' =>truckage_get_font_styles(),
	)) );
	
	/** H6 font style **/
	
	$wp_customize->add_setting('h6_font_style', array(
		'default'        => 'Normal',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_font_style',
		array(
		'label'      => __('Font Style', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_font_style',
		'type'       => 'select',
		'choices' =>array(
			'Normal' => 'Normal',
			'Italic' => 'Italic',
			'Oblique'=> 'Oblique',
			'Inherit'=> 'Inherit',
		),
	)) );
	
	/** H6 font Weight **/
	
	$wp_customize->add_setting('h6_font_weight', array(
		'default'        => '500',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_font_weight',
		array(
		'label'      => __('Font Weight', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_font_weight',
		'type'       => 'select',
		'choices' =>array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		),
	)) );
	
	/** H6 font size**/
	
	$wp_customize->add_setting('h6_font_size', array(
		'default'        => '14',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_font_size',
		array(
		'label'      => __('Font Size, px', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_font_size',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 6,
			'max'  => 50,
			'step' => 1,
		),
	)) );
	
	/** H6 Line Height**/
	
	$wp_customize->add_setting('h6_line_height', array(
		'default'        => '1.139',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_line_height',
		array(
		'label'      => __('Line Height', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_line_height',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => 1.0,
			'max'  => 3.0,
			'step' => 0.1,
		),
	)) );

	/** H6 Letter Spacing**/
	
	$wp_customize->add_setting('h6_letter_spacing', array(
		'default'        => '0',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_letter_spacing',
		array(
		'label'      => __('Letter Spacing, px', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_letter_spacing',
		'type'       => 'number',
		'input_attrs' => array(
			'min'  => -10,
			'max'  => 10,
			'step' => 1,
		),
	)) );
	
	/**H6 Text Align**/
	
	$wp_customize->add_setting('h6_text_align', array(
		'default'        => 'Inherit',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_control(
	new WP_Customize_Control($wp_customize,'h6_text_align',
		array(
		'label'      => __('Text Align', 'h6_heading'),
		'section'    => 'h6_heading',
		'settings'   => 'h6_text_align',
		'type'       => 'select',
		'choices' => array(
			'Inherit' => 'Inherit',
			'Center' => 'Center',
			'Right' => 'Right',
			'Left' => 'Left',
			'Justify' => 'Justify',
		),
	)) );
	
	/*--------------------------------------------------------------------------------------------------------------------
													Header  
--------------------------------------------------------------------------------------------------------------------*/
	
	
	/** Section header **/
	
	$wp_customize->add_section('header', array(
		'title'      => __( 'Header', 'header' ),
		'priority'   => 30,
	));
	
	/** Background color for top **/
	
	$wp_customize->add_setting( 'top_bgcolor', array(
		'default' => apply_filters( 'top_bgcolor', '#212331' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	$wp_customize->add_setting( 'top_txtcolor', array(
		'default' => apply_filters( 'top_txtcolor', '#ffffff' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	/** Background color for header **/
	
	$wp_customize->add_setting( 'header_bgcolor', array(
		'default' => apply_filters( 'header_bgcolor', '#000' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	$wp_customize->add_setting('header_bgimg', array(
		'transport' => 'refresh',
		'height'	=> 40,
	));
	
	
	
	
	/** Text color for header **/
	
	$wp_customize->add_setting( 'header_txtcolor', array(
		'default' => apply_filters( 'header_txtcolor', '#ffffff' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	
	/** To top button color **/
	
	
	$wp_customize->add_setting( 'button_to_top', array(
		'default' => true,
		'type'           => 'option',
		'transport'		 => 'refresh',
	));
	
	
	$wp_customize->add_setting( 'button_top_color', array(
		'default' => apply_filters( 'button_top_color', '#dd1b3c' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	
	/** Preloader image **/
	
	
	$wp_customize->add_setting( 'preload', array(
		'default' => true,
		'type'           => 'option',
		'transport'		 => 'refresh',
	));
	
	$wp_customize->add_setting('preloader', array(
		'transport' => 'refresh',
		'height'    => 325,
	));
	
	
	
	/** Controls for header settings **/
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'top_bgcolor',
	array(
		'label'      => __( 'Top Panel Background Color', 'header' ),
		'section'    => 'header',
		'settings'   => 'top_bgcolor',
	) ));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'top_txtcolor',
	array(
		'label'      => __( 'Top Panel Text Color', 'header' ),
		'section'    => 'header',
		'settings'   => 'top_txtcolor',
	) ));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'header_bgcolor',
	array(
		'label'      => __( 'Background Color', 'header' ),
		'section'    => 'header',
		'settings'   => 'header_bgcolor',
	) ));
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'header_bgimg', array(
		'label' => __('Background Image', 'header'),
		'section'=> 'header',
		'settings'=> 'header_bgimg',    
	)));
	
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'header_txtcolor',
	array(
		'label'      => __( 'Text Color', 'header' ),
		'section'    => 'header',
		'settings'   => 'header_txtcolor',
	) ));
	
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'button_to_top',
	array(
		'label'      => __( 'Show To Top Button', 'header' ),
		'section'    => 'header',
		'settings'   => 'button_to_top',
		'type'		 => 'checkbox',
	) ));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'button_top_color',
	array(
		'label'      => __( 'To Top Background', 'header' ),
		'section'    => 'header',
		'settings'   => 'button_top_color',
	) ));
	
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'preload',
	array(
		'label'      => __( 'Show Preloader', 'header' ),
		'section'    => 'header',
		'settings'   => 'preload',
		'type'		 => 'checkbox',
	) ));
	
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'customizer_setting_two_control', array(
		'label' => __('Preloader Image', 'header'),
		'section'=> 'header',
		'settings'=> 'preloader',    
	)));
	
	
	
	
	/*--------------------------------------------------------------------------------------------------------------------
													Footer  
--------------------------------------------------------------------------------------------------------------------*/
	
	
	
	/** Section footer **/
	
	$wp_customize->add_section('gec_footer', array(
		'title'      => __( 'Footer', 'footer-contact' ),
		'priority'   => 30,
	));
	
	/** Background Color for footer**/
	
	$wp_customize->add_setting( 'footer_bgcolor', array(
		'default' => apply_filters( 'footer_bgcolor', '#212331' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	/** Text color for footer **/
	
	$wp_customize->add_setting( 'footer_textcolor', array(
		'default' => apply_filters( 'footer_textcolor', '#fff' ),
		'sanitize_callback' => 'sanitize_hex_color',
		'type'           => 'option',
	));
	
	/** Footer contact **/
	
	$wp_customize->add_setting('footer_phone', array(
		'default'        => '+91',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_setting('footer_mail', array(
		'default'        => 'info@domain.com',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	$wp_customize->add_setting('footer_contact', array(
		'default'        => 'A street',
		'capability'     => 'edit_theme_options',
		'type'           => 'option',
	));
	
	/** Controls for footer settings **/
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'footer_bgcolor',
	array(
		'label'      => __( 'Background Color', 'footer-contact' ),
		'section'    => 'gec_footer',
		'settings'   => 'footer_bgcolor',
	) ));
	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_textcolor',
	array(
		'label'      => __( 'Text Color', 'footer-contact' ),
		'section'    => 'gec_footer',
		'settings'   => 'footer_textcolor',
	) ) );
	
	$wp_customize->add_control(
	new WP_Customize_Color_Control($wp_customize,'footer_phone',
	array(
		'label'      => __('Phone', 'footer-contact'),
		'section'    => 'gec_footer',
		'settings'   => 'footer_phone',
		'priority'   => 10,
		'type'       => 'text'
	)) );
	
	$wp_customize->add_control(
	new WP_Customize_Color_Control($wp_customize,'footer_contact',
	array(
		'label'      => __('Contact', 'footer-contact'),
		'section'    => 'gec_footer',
		'settings'   => 'footer_contact',
		'priority'   => 10,
		'type'       => 'textarea'
	))  
	);	
	
	$wp_customize->add_control(
	new WP_Customize_Color_Control($wp_customize,'footer_mail',
	array(
		'label'      => __('Mail', 'footer-contact'),
		'section'    => 'gec_footer',
		'settings'   => 'footer_mail',
		'priority'   => 10,
		'type'       => 'text'
	))  
	);	
	
}
add_action( 'customize_register', 'truckage_customize_register' );
?>